Shape

Struct Shape 

pub struct Shape { /* private fields */ }
The shape of a rigid body.

Contains a rotation/translation offset and a size.

Implementations

Source

impl Shape

pub fn new(size: Size2) -> Self

Return a new Shape with a zero offset and a size.

pub fn with_offset(self, offset: Vec2) -> Self

Return a new Shape with an offset and a size.