SpringJointBehaviour

Struct SpringJointBehaviour 

pub struct SpringJointBehaviour { /* private fields */ }
A joint behaviour that will move the anchored body into a position and angle relative to the anchor over time.

Implementations

Source

impl SpringJointBehaviour

pub fn new(rigidness: f32) -> Option<SpringJointBehaviour>

Create a new SpringJointBehaviour with an exact rigidness value.

Rigidness describes how “snappy” the spring joint is. When it’s at 0.0, the anchored body will “jump” into position softly over one second. When it’s at 1.0, the anchored body will “jump” into position almost instantaenously.

pub fn new_lossy(rigidness: f32) -> SpringJointBehaviour